diff: changes to check.pl

Fergus Henderson fjh at cs.mu.OZ.AU
Mon Apr 27 21:36:50 AEST 1998


CVSROOT/check.pl:
	Add some more verbose output for the case where the permissions
	can't be checked because the file doesn't exist.

	The aim of this change is to help track down a bug where
	files sometimes get committed with the wrong group and/or
	wrong permissions, despite the checks here in check.pl.
	I still don't know what the bug is, but this change may
	help us track it down next time it occurs.

Index: check.pl
===================================================================
RCS file: /home/staff/zs/imp/CVSROOT/check.pl,v
retrieving revision 1.6
diff -u -u -r1.6 check.pl
--- check.pl	1997/09/10 10:59:03	1.6
+++ check.pl	1998/04/27 11:32:12
@@ -26,6 +26,7 @@
 
 #-----------------------------------------------------------------------------#
 
+$pause_before_exit = 0;
 $retval = 0;
 
 # the first argument is the CVS directory
@@ -69,7 +70,11 @@
 			}
 		}
 	} else {
-		# file not in workspace, so permission problems cannot happen
+		# file not in workspace, so presumably 
+		# permission problems cannot happen
+		print "File `$arg' not found -- " .
+			"presumably it was `cvs remove'd.\n";
+		$pause_before_exit = 1;
 		next FILE;
 	}
 
@@ -111,6 +116,13 @@
 		} else {
 			$retval = 1;
 		}
+		# we already paused, no need to pause again
+		$pause_before_exit = 0;
 	}
+}
+if ($pause_before_exit) {
+	print "Hit enter to continue: ";
+	open TTY, "/dev/tty";
+	$_ = <TTY>;
 }
 exit($retval);

-- 
Fergus Henderson <fjh at cs.mu.oz.au>  |  "I have always known that the pursuit
WWW: <http://www.cs.mu.oz.au/~fjh>  |  of excellence is a lethal habit"
PGP: finger fjh at 128.250.37.3        |     -- the last words of T. S. Garp.



More information about the developers mailing list